=======
Credits
=======

Development Team
----------------

* Leonhard Wachutka <leonhard@wachutka.eu> - idea of the tool, architecture, code
* Stefan Dvoretskii <stefan.dvoretskii@gmail.com> - code, documentation

.. _contributors-list:

Contributors
------------

* Jun Cheng <chengju@in.tum.de> - code, discussion
* Žiga Avsec <avsec@in.tum.de> - code, discussion
* Felix Brechtmann <Felix.Brechtmann@in.tum.de> - beta-testing, documentation
